==========
Categories
==========

The following methods are available under the `expr.cat` attribute.

.. currentmodule:: polars
.. autosummary::
   :toctree: api/
   :template: autosummary/accessor_method.rst

    Expr.cat.get_categories
